@@ -1,10 +1,13 @@
-"as.asc" <-
-function(x, xll=1, yll=1, cellsize=1, type=c("numeric", "factor"),
-                 lev=levels(factor(x)))
-  {
+"as.asc" <- function(x, xll=1, yll=1, cellsize=1,
+                     type=c("numeric", "factor"),
+                     lev=levels(factor(x)))
+{
+    ## Verifications
     type<-match.arg(type)
     if (!inherits(x, "matrix"))
       stop("x should be a matrix")
+
+    ## creates the attributes
     mode(x)<-"numeric"
     attr(x, "xll")<-xll
     attr(x, "yll")<-yll
@@ -13,6 +16,8 @@ function(x, xll=1, yll=1, cellsize=1, type=c("numeric", "factor"),
     if (type=="factor")
       attr(x, "levels")<-lev
     class(x)<-"asc"
+
+    ## Output
     return(x)
   }
 
